import { applyPolyfills, defineCustomElements } from 'ibiz-components/loader';

/**
 * 初始化
 *
 * @export
 */
function appInitialize() {
    var win = window;
    applyPolyfills().then(function () { return defineCustomElements(win); });
}

/**
 * 日历组件
 */
var iBizCalendarVue = {
    props: {
        option: {
            type: Object,
            default: function () { }
        },
        items: {
            type: Array,
            default: function () { return []; }
        }
    },
    data: function () {
        return {
            calendar: null
        };
    },
    mounted: function () {
        this.calendar = this.$refs.iBizCalendar;
    },
    methods: {
        calendarDidLoad: function () {
            this.setOption();
            this.setItems();
        },
        setOption: function (option) {
            this.calendar.option = option || this.option;
        },
        setItems: function (items) {
            this.calendar.items = items || this.items;
        },
        dataChangeEmit: function (e) {
            this.$emit('item-change', e.detail);
        },
        itemClickEmit: function (e) {
            this.$emit('item-click', e.detail);
        },
        newItemEmit: function (e) {
            this.$emit('item-new', e.detail);
        }
    },
    watch: {
        option: function () {
            this.setOption();
        },
        items: function () {
            this.setItems();
        }
    },
    // 绘制组件
    render: function (h) {
        return h('ibiz-calendar', {
            ref: 'iBizCalendar',
            on: {
                'did-load': this.calendarDidLoad,
                'data-change': this.dataChangeEmit,
                'item-click': this.itemClickEmit,
                'new-item': this.newItemEmit
            }
        }, this.$slots.default);
    }
};

// 安装记录，避免重复安装
var Vue;
// iBiz插件安装
var install = function (_Vue) {
    if (Vue && _Vue === Vue) {
        if (process.env.NODE_ENV !== 'production') {
            console.error('[iBizComponents] already installed. Vue.use(iBizComponents) should be called only once.');
        }
        return;
    }
    Vue = _Vue;
    // Vue排除组件
    Vue.config.ignoredElements.push(/^ibiz-/);
    // 安装原生组件
    appInitialize();
    // 安装Vue组件
    Vue.component('ibiz-calendar-vue', iBizCalendarVue);
};

var index = {
    install: install,
    version: '__VERSION__'
};

export default index;
//# sourceMappingURL=ibiz-components.esm.js.map
